@@ -1,7 +1,8 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::Value;
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RunAgain, RUN_AGAIN};
+
 #[derive(FlowImpl)]
 /// Control the flow of a piece of data by waiting for a second value to be available
 #[derive(Debug)]
@@ -13,4 +14,4 @@ impl Implementation for Join {
 
         (data, RUN_AGAIN)
     }
-}
\ No newline at end of file
+}
