@@ -1,8 +1,9 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::json;
 use serde_json::Value;
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RUN_AGAIN, RunAgain};
+
 #[derive(FlowImpl)]
 /// Takes two arrays of values and produce an array of tuples of pairs of values from each input array.
 #[derive(Debug)]
@@ -18,4 +19,4 @@ impl Implementation for Zip {
         let tuples_vec: Vec<(&Value, &Value)> = tuples.collect();
         (Some(json!(tuples_vec)), RUN_AGAIN)
     }
-}
\ No newline at end of file
+}
